function computation_clbk(varargin)

% find structure and handles
swansed=findobj('Tag','swanonesed');
handles=get(swansed,'Userdata');

% waitbar
%waitbar(0,'Initializing...')
%waitbar(0.25,'25%')
%waitbar(0.5,'50%')
%waitbar(0.75,'75%'))
h= waitbar(1,'100%') ;
handles.computation.h=h ;
t = timer('TimerFcn',{@close_waitbar},'StartDelay',2); % create timer 
start(t); % start timer ;

% enable output-button
set(handles.swan1dsed.menu.output.m,'Enable','On')

%% INPUT
% parameters manually provided
d50         = handles.input.d50 ;     % micrometer
d90         = handles.input.d90 ;     % micrometer
gamma       = handles.input.gamma ;     % -
rho_w       = handles.input.denwater ;    % kg/m3 (sea water)
rho_s       = handles.input.densediment ;    % kg/m3
porosity    = handles.input.porosity ;     % volume ratio
r           = handles.input.r ;     % bed rougness in m
nu          = handles.input.nu ; 

% parameters calculated by the above
delta       = (rho_s-rho_w)./rho_w ;
Dstar       = d50.*(delta*9.81/nu.^2)^0.333 ;

% read SWAN output and use numerical dat
num_data_output_swan = handles.openproject.outputdata.data ;

% distinguish the variables
Xp      = num_data_output_swan(:,1) ;
Yp      = num_data_output_swan(:,2) ;
Hsig    = num_data_output_swan(:,3) ;
RTpeak  = num_data_output_swan(:,4) ;
Tm01    = num_data_output_swan(:,5) ;
Tm_10   = num_data_output_swan(:,6) ;
Dir     = num_data_output_swan(:,7) ;
Dspr    = num_data_output_swan(:,8) ;
Depth   = num_data_output_swan(:,9) ;
Setup   = num_data_output_swan(:,10) ;

%% WAVE FIELD CHARACTERISTICS
Depth_neg       = -Depth ;
Dir_180         = Dir-180 ;
sincos          = sin(Dir.*pi/180).*cos(Dir.*pi/180) ;
L0              = 1.56.*Tm_10.^2 ;

% wave length determination
Depth(Depth==-99)=0;

for m = 1:length(L0);
    if ((Depth(m)./L0(m)) > 0.36);
    L(m) = L0(m);
    else
    L(m) = sqrt(9.81.*Depth(m)).*(1-Depth(m)./L0(m)).*Tm_10(m);
    end
    Lv=0;
    while abs((L(m)-Lv)/L(m))>0.005;
        Lv=L(m);
        Lstar=L0(m).*tanh(2*pi.*Depth(m)/Lv);
        L(m)=(2.*Lstar+Lv)/3;
    end
end

L = L' ;     % from row to column

% variable calculation
k       = 2.*pi./L ;
a       = Hsig./2./sinh(2*pi.*Depth./L) ;
fw      = exp(-5.977+5.213*(a./r).^(-0.194)) ;
C       = 18.*log10(12.*Depth./r) ;
Hm      = 0.88./k.*tanh(0.78.*k.*Depth./0.88) ;

%% DISCHARGES ON THE BED

for ii=1:length(Hm) ;
if ii==1
    Hm_min(ii,1) = 0 ;
else
    Hm_min(ii,1) = min(1,(-Hsig(ii-1)/1.41./Hm(ii))^2) ;
end
end

Hm_min(size(Hm),1) = 1 ; % last value of the vector is 1

n       = 0.5*(1+((4.*pi.*Depth./L)./(sinh(4.*pi.*Depth./L)))) ;

for z=1:length(Hsig)
E(z,1)  = (1/8)*(rho_w)*9.81*Hsig(z,1)^2 ;
end

%% SEDIMENT TRANSPORT
Sxy     = E.*n.*sincos ;

for z=1:length(Sxy) ;
    if (z+1)<=length(Sxy) ;
    diff_Sxy_dx(z+1,1)          = max((Sxy(z)-Sxy(z+1))./(Xp(z+1)-Xp(z)),0) ;
    else
    diff_Sxy_dx(z+1,1)          = 0 ;
    end
end

diff_Sxy_dx(length(diff_Sxy_dx)) = [] ;         % make vector smaller

%% VAN RIJN

% Comparison of variables Excel-sheet
% x = Xp
% h = Depth
% H = Hsig
% Tm-1 = Tm_10
% L = L(m)
% u = V
% because the Van Rijn formula have been calibrated with Tp with standard Jonswap 
%a fictive Tp is used in formulas below.
Tp  = 1.1.*Tm_10;

if d50<0.0005 
    ucw     = 0.24*(delta.*9.81)^0.66*d50.^0.33.*Tp.^0.33 ;
    ucc     = 0.19.*(d50)^0.1*log10(12.*Depth./3./d90) ;
else
    ucw     = 0.95*(delta.*9.81)^0.57*d50.^0.43.*Tp.^0.14 ;
    ucc     = 8.5.*(d50)^0.6*log10(12.*Depth./3./d90) ;
end
    
uw      = 3.141.*Hsig./(Tp.*sinh(2*pi./L.*Depth)) ;

for o=1:length(Sxy)
V(o,1)    = (diff_Sxy_dx(o).*pi.*C(o))./(uw(o).*rho_w.*sqrt(2.*9.81.*fw(o))) ;
end

ue      = V+(gamma.*uw) ;
beta    = V./(V+uw) ;
uc      = beta.*ucc+(1-beta).*ucw ;
Me      = max((ue-uc)./sqrt(delta*9.81.*d50),0) ;

%% SEDIMENT TRANSPORT

Sb      = 0.015.*rho_s.*V.*Depth.*(d50./Depth).^1.2.*Me.^1.5 ;   % bed load
Ss      = 0.012.*rho_s.*V.*d50.*Me.^2.4.*Dstar.^(-0.6) ;         % suspended load
Stot    = Sb+Ss ;    % total load

Stotal1 = sum(Stot).*(Xp(3)-Xp(2));     % kg/s
Stotal2 = Stotal1./rho_s;               % m3/s including volume of void
Stotal3 = Stotal2./porosity;            % m3/s
Stotal4 = Stotal3.*365*3600;            % m3/year        
Shalf   = Stotal4.*0.5;                 %

Stotal  = round(Shalf/1000) *1000 ;              % round up yearly transport
handles.output.stotal = Stotal ;

% create handles for plots and tables
handles.output.xp           = Xp ;
handles.output.depth_neg    = Depth_neg;
handles.output.dir180       = Dir_180;
handles.output.dspr         = Dspr;
handles.output.v             = V ;
handles.output.sb           = Sb ;
handles.output.ss           = Ss ;
handles.output.stot         = Stot ;

% Set handles to 'Userdata' property
set(swansed,'UserData',handles);

end