function output_plots_clbk(varargin)

% find structure and handles
swansed=findobj('Tag','swanonesed');
handles=get(swansed,'Userdata');

clf(figure(411))
clf(figure(511))

%% PlOT 1

Xp          = handles.output.xp ;
Depth_neg   = handles.output.depth_neg;
Dir_180     = handles.output.dir180 ;
Dspr        = handles.output.dspr ;
V           = handles.output.v ;
Sb          = handles.output.sb ;
Ss          = handles.output.ss ;
Stot        = handles.output.stot ;

% legend to explain the variables
%text(0,-.5,{'Xp = Distance to Shore','d = Water Depths'})
%text(0,-.5,{'n = Number of Points','Dir-180 = Wave Direction minus 180 Degrees'})
%text(0,-.5,{'n = Number of Points','Dspr = Directional Spreading'})
%text(0,-.5,{'Xp = Distance to Shore', 'V = Longshore Velocity'})

%% PlOT 2
handles.output.fig1=figure(411);
set(handles.output.fig1,'Menubar','none','NumberTitle','off','Name','SwanOneSed - Input Parameters Plot','Position',[100 100 800 800]) ;

% DEPTH
% figure distance to shore (Xp) to water depth (Depth)
subplot(2,2,1)
title('Water Depth')
plot(Xp,Depth_neg,'k')
xlabel('distance (m)')
ylabel('d (m)')

% WAVE DIRECTION MINUS 180 DEGREES
% figure number of points (n) to direction (dir-180)
subplot(2,2,2)
title('Wave Direction')
plot(Xp,Dir_180,'b')
xlabel('distance (m)')
ylabel('Dir-180 (degrees)')

% DIRECTIONAL SPREADING
% figure number of points (n) to directional spreading (Dspr)
subplot(2,2,3)
title('Directional Spreading')
plot(Xp,Dspr,'r')
xlabel('distance (m)')
ylabel('Dspr (degrees)')

% LONGSHORE VELOCITY
% figure distance to shore (n) to longshore flow velocities
subplot(2,2,4)
title('Longshore Velocity')
plot(Xp,V,'g')
xlabel('distance (m)')
ylabel('V (m/s)')

%% PLOT 2
handles.output.fig2=figure(511);
set(handles.output.fig2,'Menubar','none','NumberTitle','off','Name','SwanOneSed - Sediment Transport Plot','Position',[950 100 800 800]);

% DISTRIBUTION OF SEDIMENT TRANSPORT
% figure distance to shore and
plot(Xp,Sb,Xp,Ss,Xp,Stot)
title('Distribution of Sediment Transport')
xlabel('Xp (m)')
ylabel('S (kg/m/s)')
legend('Sb = Bed Load', 'Ss = Suspended Load', 'Stot = Total Sediment Transport')

%% TEXTBOX

% textbox with the magnitude of the yearly sediment transport
handles.output.textbox1=annotation(handles.output.fig2,'textbox','position',[0.22,0.63,0.5,0.1],...
           'String', 'Total sediment transport','fontsize',10,'EdgeColor','none');

% textbox with the magnitude of the yearly sediment transport
handles.output.textbox1=annotation(handles.output.fig2,'textbox','position',[0.25,0.6,0.10,0.1],...
           'String', 'text','fontsize',20,'EdgeColor','none');
set(handles.output.textbox1,'String', num2str(handles.output.stotal));

% textbox with the units of the yearly sediment transport
handles.output.textbox2=annotation(handles.output.fig2,'textbox','position',[0.35,0.6,0.10,0.1],...
           'String', 'text','fontsize',20,'EdgeColor','none');
       set(handles.output.textbox2,'String', 'm3/year');

% Set handles to 'Userdata' property
set(swansed,'UserData',handles);

end 